
class ReadResult():
    def __init__(self):
        self.text = ""
        self.version = 0
        self.has_error = False
        self.read_time = 0
        self.raw_binary_string = ""
        self.output_img = None
    